@@ -135,10 +135,7 @@ impl Header {
     /// use noodles_vcf::{self as vcf, header::Filter};
     ///
     /// let header = vcf::Header::builder()
-    ///     .add_filter(Filter::new(
-    ///         String::from("q10"),
-    ///         String::from("Quality below 10"),
-    ///     ))
+    ///     .add_filter(Filter::new("q10", "Quality below 10"))
     ///     .build();
     ///
     /// let filters = header.filters();
@@ -225,12 +222,12 @@ impl Header {
     /// use noodles_vcf::{self as vcf, header::Contig};
     ///
     /// let header = vcf::Header::builder()
-    ///     .add_contig(Contig::new(String::from("sq0")))
+    ///     .add_contig(Contig::new("sq0"))
     ///     .build();
     ///
     /// let contigs = header.contigs();
     /// assert_eq!(contigs.len(), 1);
-    /// assert_eq!(contigs[0], Contig::new(String::from("sq0")));
+    /// assert_eq!(contigs[0], Contig::new("sq0"));
     /// ```
     pub fn contigs(&self) -> &Contigs {
         &self.contigs
@@ -574,7 +571,7 @@ impl FromStr for Header {
 
         let mut has_header = false;
 
-        while let Some(line) = lines.next() {
+        for line in &mut lines {
             if line.starts_with("#CHROM") {
                 builder = parse_header(builder, line)?;
                 has_header = true;
